aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--lib/http.c3
1 files changed, 2 insertions, 1 deletions
diff --git a/lib/http.c b/lib/http.c
index 876dbac2e..850731ce3 100644
--- a/lib/http.c
+++ b/lib/http.c
@@ -997,7 +997,8 @@ CURLcode Curl_http(struct connectdata *conn)
headers = headers->next;
}
- http->postdata = NULL; /* nothing to post at this point */
+ http->postdata = NULL; /* nothing to post at this point */
+ Curl_pgrsSetUploadSize(data, 0); /* upload size is 0 atm */
switch(data->set.httpreq) {